<?php
/*
Plugin Name: FlightLog
Text Domain: flightlog
Plugin URI: http://www.zavedil.com/flightlog-for-wordpress
Description: Wordpress plugin to keep track of your flights and to map them nicely.
Version: 3.0.2
Author: Assen Totin
Author URI: http://www.zavedil.com
License: GPL2

    Copyright 2012-2019  Assen Totin  (email : assen.totin@gmail.com)
	Copyright 2019 Sascha Nehls (email: funkymail@gmx.de)

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License, version 2, as 
    published by the Free Software Foundation.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

global $flightlog_db_version;
$flightlog_db_version = get_option("flightlog_db_version");
global $flightlog_measures;
$flightlog_measures = get_option("flightlog_measures");
global $flightlog_advanced;
$flightlog_advanced = get_option("flightlog_advanced");
global $flightlog_gmaps_key;
$flightlog_gmaps_key = get_option("flightlog_gmaps_key");
global $flightlog_gmaps_key_server;
$flightlog_gmaps_key_server = get_option("flightlog_gmaps_key_server");

// Create database
function flightlog_db_create() {
	global $wpdb;
	global $flightlog_db_version;

	if ($flightlog_db_version == "2.0")
		return;

	require_once(ABSPATH . 'wp-admin/includes/upgrade.php');

	// Initial setup
	if (!$flightlog_db_version) {
	        $table_name = $wpdb->prefix . "flightlog_carriers";
        	$sql = "CREATE TABLE $table_name (
	                id smallint unsigned NOT NULL AUTO_INCREMENT,
        	        name varchar(255),
                	UNIQUE KEY id (id)
	        ) CHARSET=utf8;";
        	dbDelta($sql);

	        $table_name = $wpdb->prefix . "flightlog_aircrafts";
        	$sql = "CREATE TABLE $table_name (
                	id smallint unsigned NOT NULL AUTO_INCREMENT,
	                name varchar(255),
					engines tinyint unsigned,
        	        UNIQUE KEY id (id),
					KEY(engines)
	        ) CHARSET=utf8;";
        	dbDelta($sql);

	        $table_name = $wpdb->prefix . "flightlog_airports";
        	$sql = "CREATE TABLE $table_name (
                	id smallint unsigned NOT NULL AUTO_INCREMENT,
			name varchar(255),
        	        iata varchar(16),
			lat decimal(10,7),
			lng decimal(10,7),
        	        UNIQUE KEY id (id)
	        ) CHARSET=utf8;";
        	dbDelta($sql);

		$table_name = $wpdb->prefix . "flightlog_flights";
		$sql = "CREATE TABLE $table_name (
			id int unsigned NOT NULL AUTO_INCREMENT,
			user smallint unsigned,
			dt date,
			airport_from smallint unsigned,
			airport_to smallint unsigned,
			carrier smallint unsigned,
			aircraft smallint unsigned,
			distance smallint unsigned,
			duration decimal(3,1),
			ifr_vfr enum('IFR', 'VFR'),
			day_night enum('day', 'night'),
			approaches smallint unsigned,
			landings smallint unsigned,
			plane_id varchar(255),
			UNIQUE KEY id (id),
			KEY user (user),
			KEY airport_from (airport_from),
			KEY airport_to (airport_to),
			KEY carrier (carrier),
			KEY ifr_vfr (ifr_vfr),
			KEY approaches (approaches),
			KEY landings (landings),
			KEY plane_id (plane_id)
		) CHARSET=utf8;";
		dbDelta($sql);

		$table_name = $wpdb->prefix . "flightlog_flights_remarks";
		$sql = "CREATE TABLE $table_name (
			flight_id int unsigned,
			remark text,
			KEY(flight_id)
		) CHARSET=utf8;";
		dbDelta($sql);

		update_option("flightlog_db_version", "2.0");
		update_option("flightlog_measures", "Metric");
		update_option("flightlog_advanced", 0);
	}
	else {
		if ($flightlog_db_version == "1.0") {
			// Upgrade 1.0 to 2.0
			$table_name = $wpdb->prefix . "flightlog_flights";
			$sql = "ALTER TABLE $table_name 
				ADD COLUMN ifr_vfr enum('IFR', 'VFR'), 
				ADD COLUMN day_night enum('day', 'night'),
				ADD COLUMN approaches smallint unsigned,
				ADD COLUMN landings smallint unsigned,
				ADD COLUMN plane_id varchar(255),
				ADD KEY(ifr_ivr),
				ADD KEY(day_night), 
				ADD KEY(approaches),
				ADD KEY(landings),
				ADD KEY(plane_id)
			";
			dbDelta($sql);

			$table_name = $wpdb->prefix . "flightlog_aircrafts";
		    $sql = "ALTER TABLE $table_name 
				ADD COLUMN engines tinyint unsigned,
				ADD	KEY(engines)
			";
		    dbDelta($sql);

			$table_name = $wpdb->prefix . "flightlog_flights_remarks";
			$sql = "CREATE TABLE $table_name (
				flight_id int unsigned,
				remark text,
				KEY(flight_id)
			) CHARSET=utf8;";
			dbDelta($sql);

			add_option("flightlog_advanced", 0);
			update_option("flightlog_db_version", "2.0");
			$flightlog_db_version = "2.0";
		}
		// else if ($flightlog_db_version == "2.0") {
			// Placeholder for next upgrade 2.0 -> 3.0 
		// }
	}
}

// Delete database tables after plugin uninstall
function flightlog_db_delete() {

	// Delete custom tables
	global $wpdb;

	$table_name = $wpdb->prefix . "flightlog_carriers";
	$sql = "DROP TABLE IF EXISTS $table_name";
	$wpdb->query($sql);

	$table_name = $wpdb->prefix . "flightlog_aircrafts";
	$sql = "DROP TABLE IF EXISTS $table_name";
	$wpdb->query($sql);
    
	$table_name = $wpdb->prefix . "flightlog_airports";
	$sql = "DROP TABLE IF EXISTS $table_name";
	$wpdb->query($sql);

	$table_name = $wpdb->prefix . "flightlog_flights";
	$sql = "DROP TABLE IF EXISTS $table_name";
	$wpdb->query($sql);

	$table_name = $wpdb->prefix . "flightlog_flights_remarks";
	$sql = "DROP TABLE IF EXISTS $table_name";
	$wpdb->query($sql);

	// Delete settings
	delete_option( 'flightlog_db_version' );
	delete_option( 'flightlog_measures' );
	delete_option( 'flightlog_advanced' );
	delete_option( 'flightlog_gmaps_key' );
	delete_option( 'flightlog_gmaps_key_server' );

}

function flightlog_admin_menu() {
	add_options_page('FlightLog Settings', 'FlightLog', 'manage_options', 'flightlog-settings-menu', 'flightlog_settings');
	add_management_page('FlightLog Entries', 'FlightLog', 'publish_pages', 'flightlog-entries-menu', 'flightlog_entries');
}


function flightlog_settings() {
	if ( !current_user_can( 'manage_options' ) )  {
		wp_die( __( 'You do not have sufficient permissions to access this page.' ) );
	}

	echo '<h3>FlightLog Settings</h3>';
	flighlog_settings_sys();	
	echo '<hr width=100%>';
	echo '<table width=100%><tr><td valign=top>';
	flighlog_settings_section("carriers");
	echo '</td><td bgcolor=#DDDDDD valign=top>';
	flighlog_settings_section("aircrafts");
	echo '</td><td valign=top>';
	flighlog_settings_section("airports");
	echo '</td></tr></table>';
}


function flighlog_settings_sys() {
	global $wpdb;
	global $flightlog_measures;
	global $flightlog_advanced;
	global $flightlog_gmaps_key;
	global $flightlog_gmaps_key_server;

	// Update
	if (isset($_POST['measures']) && ($_POST['measures'] != $flightlog_measures)) {
		update_option("flightlog_measures", $_POST['measures']);
		$flightlog_measures = get_option("flightlog_measures");
	
		// Recalc distances if measures changed
		$results = $wpdb->get_results('SELECT ff.id, fa1.lat AS lat1, fa1.lng AS lng1, fa2.lat AS lat2, fa2.lng AS lng2 FROM ' . $wpdb->prefix . 'flightlog_flights ff JOIN '.$wpdb->prefix.'flightlog_airports fa1 ON fa1.id=ff.airport_from JOIN '.$wpdb->prefix.'flightlog_airports fa2 ON fa2.id=ff.airport_to');
		if ($results) {
			foreach ($results as $result) {
				$dist = flightlog_calc_dist($result->lat1, $result->lng1, $result->lat2, $result->lng2);
				$wpdb->query($wpdb->prepare("UPDATE " . $wpdb->prefix . "flightlog_flights SET distance=%d WHERE id=%d", $dist, $result->id));
			}
		}
	}

	if (isset($_POST['gmaps_key']) && ($_POST['gmaps_key'] != $flightlog_gmaps_key)) {
		update_option("flightlog_gmaps_key", $_POST['gmaps_key']);
		$flightlog_gmaps_key = $_POST['gmaps_key'];
	}

	if (isset($_POST['gmaps_key_server']) && ($_POST['gmaps_key_server'] != $flightlog_gmaps_key_server)) {
		update_option("flightlog_gmaps_key_server", $_POST['gmaps_key_server']);
		$flightlog_gmaps_key_server = $_POST['gmaps_key_server'];
	}

	if (isset($_POST['advanced']) && ($_POST['advanced'] != $flightlog_advanced)) { 
		update_option("flightlog_advanced", $_POST['advanced']);
		$flightlog_advanced = get_option("flightlog_advanced");
	}

	// Display all settings
	echo __( 'Current measures', 'flightlog' ).": <a href=# onClick=\"javascript:fl_overlay_add_sys('" . $flightlog_measures . "')\">" . $flightlog_measures . "</a>";

	$display_gmaps_key = ($flightlog_gmaps_key) ? $flightlog_gmaps_key : __( 'Not set', 'flightlog');
	echo "<p>".__( 'Google Maps client key', 'flightlog' ).": <a href=# onClick=\"javascript:fl_overlay_add_sys_gmaps_key('gmaps_key','Google Maps client key','" . $flightlog_gmaps_key . "')\">" . $display_gmaps_key . "</a>";

	$display_gmaps_key_server = ($flightlog_gmaps_key_server) ? $flightlog_gmaps_key_server : __( 'Not set', 'flightlog');
	echo "<p>".__( 'Google Maps server key', 'flightlog' ).": <a href=# onClick=\"javascript:fl_overlay_add_sys_gmaps_key('gmaps_key_server','Google Maps server key','" . $flightlog_gmaps_key_server . "')\">" . $display_gmaps_key_server . "</a>";

	echo "<p>".__( 'Advanced flight options', 'flightlog' ).": <a href=# onClick=\"javascript:fl_overlay_add_sys_adv('" . $flightlog_advanced . "')\">"; 
	echo ($flightlog_advanced) ? __( 'On', 'flightlog' ) : __( 'Off', 'flightlog' );
	echo "</a>";
}

function flighlog_settings_section($section) {
	global $wpdb;
	global $flightlog_advanced;
	global $flightlog_gmaps_key_server;

	wp_enqueue_script('fl_js', plugins_url( 'flightlog.js' , __FILE__ ));
	wp_enqueue_style('fl_css', plugins_url( 'flightlog.css' , __FILE__ ));

	// Insert new record, if submitted
	if(isset($_POST["section"]) && $_POST["section"] == $section && $_POST["Submit"] == "Add") {
		if ($section == "airports") {
			$_POST["iata"] = strtoupper($_POST["iata"]);
			$string = file_get_contents('https://maps.google.com/maps/api/geocode/json?key=' . $flightlog_gmaps_key_server . '&address='.$_POST["name"].'+'.$_POST["iata"].'+airport&sensor=false');
			$result = json_decode($string, true);
			$lat = $result['results'][0]['geometry']['location']['lat'];
			$lng = $result['results'][0]['geometry']['location']['lng'];
			$wpdb->query($wpdb->prepare("INSERT INTO " . $wpdb->prefix . "flightlog_" . $section . " (name, iata, lat, lng) VALUES (%s, %s, %f, %f)", $_POST["name"], $_POST["iata"], $lat, $lng));
		}
		else if ($section == 'aircrafts')
			$wpdb->query($wpdb->prepare("INSERT INTO " . $wpdb->prefix . "flightlog_" . $section . " (name, engines) VALUES ('%s', %d)", $_POST["name"], $_POST["engines"]));
		else
			$wpdb->query($wpdb->prepare("INSERT INTO " . $wpdb->prefix . "flightlog_" . $section . " (name) VALUES (%s)", $_POST["name"]));
	}

	// Update a record
	if(isset($_POST["section"]) && $_POST["section"] == $section && $_POST["Submit"] == "Update") {
		if ($section == "airports") {
			// Get old coordinates
			$results = $wpdb->get_results('SELECT * FROM ' . $wpdb->prefix . 'flightlog_' . $section . ' WHERE id=' . $_POST["id"]);
			if ($results) {
				foreach ($results as $result) {
					$old_lat = $result->lat;
					$old_lng = $result->lng;
				}
			}

			// Update DB
			$_POST["iata"] = strtoupper($_POST["iata"]);
			$wpdb->query($wpdb->prepare("UPDATE " . $wpdb->prefix . "flightlog_" . $section . " SET name='%s', iata='%s', lat=%f, lng=%f WHERE id=%d", $_POST["name"], $_POST["iata"], $_POST["lat"], $_POST["lng"], $_POST["id"]));

			// Recalc distances if coords were updated with mode than 1 degree
			if ((intval($old_lat) != intval($_POST["lat"])) || (intval($old_lng) != intval($_POST["lng"]))) {
				$results = $wpdb->get_results('SELECT ff.id, fa1.lat AS lat1, fa1.lng AS lng1, fa2.lat AS lat2, fa2.lng AS lng2 FROM ' . $wpdb->prefix . 'flightlog_flights ff JOIN '.$wpdb->prefix.'flightlog_airports fa1 ON fa1.id=ff.airport_from JOIN '.$wpdb->prefix.'flightlog_airports fa2 ON fa2.id=ff.airport_to WHERE fa1.id=' . $_POST["id"] . ' OR fa2.id=' . $_POST["id"]);
				if ($results) {
					foreach ($results as $result) {
						$dist = flightlog_calc_dist($result->lat1, $result->lng1, $result->lat2, $result->lng2);
						$dur = flightlog_calc_dur($dist);

						$wpdb->query($wpdb->prepare("UPDATE " . $wpdb->prefix . "flightlog_flights SET distance=%d, duration=%f WHERE id=%d", $dist, $dur, $result->id));
					}
				}
			}
		}
		else if ($section == 'aircrafts')
			$wpdb->query($wpdb->prepare("UPDATE " . $wpdb->prefix . "flightlog_" . $section . " SET name='%s', engines=%d WHERE id=%d", $_POST["name"], $_POST["engines"], $_POST["id"]));
		else
			$wpdb->query($wpdb->prepare("UPDATE " . $wpdb->prefix . "flightlog_" . $section . " SET name='%s' WHERE id=%d", $_POST["name"], $_POST["id"]));
	}

	// Delete a record
	if(isset($_POST["section"]) && $_POST["section"] == $section && $_POST["Submit"] == "Delete") {
		$wpdb->query($wpdb->prepare("DELETE FROM " . $wpdb->prefix . "flightlog_" . $section . " WHERE id=%d", $_POST["id"]));
	}

	echo '<p><b>' . $section . ':</b></p>';

	// Show new record form
	echo '<form name="form_' . $section . '" method="post" action="">';
	echo '<input type=hidden name=section value=' . $section . '>';
	echo '<p><b>'.__( 'Add new', 'flightlog').':</b><br>'.__( 'Name', 'flightlog').': ';
	echo '<input type="text" name="name" value="" size="20">';
	if ($section == "airports")
                echo ' <a href=https://en.wikipedia.org/wiki/IATA_airport_code target=_blank>IATA</a>: <input type="text" name="iata" value="" size="4">';
	else if (($section == "aircrafts") && $flightlog_advanced)
		echo __( 'Engines', 'flightlog').': <select name="engines"><option value=1>1</option><option value=2>2</option><option value=3>3</option><option value=4>4</option></select>';
	echo '<input type="submit" name="Submit" class="button-primary" value="Add">';
	echo '</p>';
	echo '</form>';

	// Display all records
	echo '<p><b>'.__( 'Existing', 'flightlog').':</b></p>';
	if ($section == "aircrafts") 
		$results = $wpdb->get_results('SELECT ff.id AS ffid, fa.id, fa.name, fa.engines, COUNT(*) AS cnt FROM ' . $wpdb->prefix . 'flightlog_aircrafts fa LEFT JOIN ' . $wpdb->prefix . 'flightlog_flights ff ON ff.aircraft=fa.id GROUP BY fa.id ORDER BY fa.name');
	else if ($section == "airports")
		$results = $wpdb->get_results('SELECT ff.id AS ffid, fa.id, fa.name, COUNT(*) AS cnt, fa.iata, fa.lat, fa.lng FROM ' . $wpdb->prefix . 'flightlog_airports fa LEFT JOIN ' . $wpdb->prefix . 'flightlog_flights ff ON (ff.airport_from=fa.id OR ff.airport_to=fa.id) GROUP BY fa.id ORDER BY fa.name');
	else if ($section == "carriers")
		$results = $wpdb->get_results('SELECT ff.id AS ffid, fc.id, fc.name, COUNT(*) AS cnt FROM ' . $wpdb->prefix . 'flightlog_carriers fc LEFT JOIN ' . $wpdb->prefix . 'flightlog_flights ff ON ff.carrier=fc.id GROUP BY fc.id ORDER BY fc.name');

	if ($results) {
		echo '<table>';
		foreach ($results as $result) {
			if (($result->cnt == 1) && ($refult->ffid == ""))
				$show_del = 1;
			else
				$show_del = 0;

			echo '<tr><td>';
			echo "<a href=# onClick=\"javascript:fl_overlay_add('" . $section  .  "',"  . $result->id . "," . $show_del  .",'" . $result->name . "','" . $result->iata . "','" . $result->lat . "','" . $result->lng . "','" . $flightlog_advanced . "','" . $result->engines ."')\">";
			echo $result->name . '</a></td>';

			if ($section == "airports") {
				$result->lat = ($result->lat == "") ? "?" : (intval(10*$result->lat))/10;
				$result->lng = ($result->lng == "") ? "?" : (intval(10*$result->lng))/10;
				echo '<td>' . $result->iata .'</td>';
				echo '<td>(' . $result->lat . "/" . $result->lng .')</td>';
			}
			else if (($section == "aircrafts") && $flightlog_advanced) {
				$result->engines = ($result->engines == "") ? "N/A" : $result->engines;
				echo '<td>('.__( 'engines', 'flightlog' ).': ' . $result->engines .')</td>';
			}

			echo '</tr>';
		}
		echo '</table>';
	}
}


function flightlog_calc_dist($lat1, $lng1, $lat2, $lng2) {
	global $flightlog_measures;
	if ($flightlog_measures == "Metric")
		$R = 6371;
	else
		$R = 6371/1.609;

	$lat1 = $lat1 * 0.0174;
        $lng1 = $lng1 * 0.0174;
        $lat2 = $lat2 * 0.0174;
        $lng2 = $lng2 * 0.0174;
	
        $dist = acos(sin($lat1) * sin($lat2) + cos($lat1) * cos($lat2) * cos($lng2-$lng1)) * $R;
        $dist = intval($dist);
	$_tmp1 = intval($dist/100);
	$_tmp2 = $dist % 100;
	if ($_tmp2 < 50) 
		$dist2 = $_tmp1 . "50";
	else
		$dist2 = ($_tmp1 + 1) . "00";
	return $dist2;
}

function flightlog_calc_dur($dist) {
        global $flightlog_measures;
	if ($flightlog_measures == "Metric")
		$speed = 650;
	else
		$speed = 650/1.609;
	$_tmp = $dist / $speed;
	return $_tmp;
}

function flightlog_html_dropdown($table, $name, $mandatory, $selected) {
	global $wpdb;

	echo '<span id=' . $table . '_' . $name . '></span>';

	$js = '<script language=javascript>';
	$js .= 'var ' . $table . ' = {';
	$js .= 'mandatory: ' . $mandatory . ',';
	$js .= 'selected: ' . $selected . ',';
	$js .= 'data: [';

	$entries = $wpdb->get_results("SELECT * FROM " . $wpdb->prefix . $table . " ORDER BY name");
	if ($entries) {
		foreach($entries as $entry) {
			$js .= '{';
			$js .= 'id: ' . $entry->id . ',';

			$js .= 'name: "' . $entry->name ;
			if ($entry->iata)
				$js .= ' (' . $entry->iata . ')';
			$js .= '",';

			if ($entry->engines)
				$js .= 'engines: ' . $entry->engines . ',';

			$js .= '},';
		}
	}

	$js .= '],';
	$js .= '};';
	$js .= '</script>';

	echo $js;
}

function flightlog_html_aircraft($input, $link_engines) {
	global $wpdb;
	$aircrafts = $wpdb->get_results("SELECT * FROM " . $wpdb->prefix . "flightlog_aircrafts ORDER BY name");
	if ($aircrafts) {
		foreach($aircrafts as $aircraft) {
			$js .= 'aircrafts[' . $aircraft->id .'] = ' . $aircraft->engines . ';';
			$js2 .= 'aircrafts_names[' . $aircraft->id .'] = \'' . $aircraft->name . '\';';
		}
	}
	echo '<script language=javascript>var aircrafts=[]; var aircrafts_names=[];' . $js . $js2 . ' </script>';
}

function flightlog_html_plane_id($input, $class = '') {
	echo ' <input name=plane_id type=text class="' . $class . '" value=\''.$input.'\' placeholder=\'Aircraft ID\' size=10>';
}

function flightlog_html_ifr_vfr($input, $class = '') {
	echo ' <select name="ifr_vfr" class="margin-zero ' . $class . '"><option value=0>-- '.__( 'Flight Rules', 'flightlog' ).' --</option>';
	echo '<option value=IFR';
	echo ($input == 'IFR') ? ' selected' : '';
	echo '>IFR</option>';
	echo '<option value=VFR';
	echo ($input == 'VFR') ? ' selected' : '';
	echo '>VFR</option>';
	echo "</select>";
}

function flightlog_html_time($input, $class = '') {
	echo ' <select name="day_night" class="margin-zero ' . $class . '"><option value=0>-- '.__( 'Time', 'flightlog' ).' --</option>';
	echo '<option value=day';
	echo ($input == 'day') ? ' selected' : '';
	echo '>day</option>';
	echo '<option value=night';
	echo ($input == 'night') ? ' selected' : '';
	echo '>night</option>';
	echo "</select>";
}

function flightlog_html_approaches($input, $class = '') {
	echo ' <input name=approaches type=text class="' . $class . '"  value="'.$input.'" placeholder='.__( 'Approaches', 'flightlog' ).' size=20>'; 
}

function flightlog_html_landings($input, $class = '') {
	echo ' <input name=landings type=text class="' . $class . '" value="'.$input.'" placeholder='.__( 'Landings', 'flightlog' ).' size=20>';
}

function flightlog_entries() {
	global $current_user;
	global $wpdb;
	global $flightlog_advanced;

	if ( !current_user_can( 'publish_pages' )) 
		wp_die( __( 'You do not have sufficient permissions to access this page.' ) );

	// Process input, if any
	// WP applies magic_quotes even they are off in php.ini, so let's fcuk them away and put inside the database properly.
	$_POST = array_map('stripslashes_deep', $_POST);
	if(isset($_POST["Submit"]) && $_POST["Submit"] == 'Add') {
		if ($_POST['section'] == 'flight') {
			$results1 = $wpdb->get_results('SELECT lat, lng FROM ' . $wpdb->prefix . 'flightlog_airports WHERE id=' . $_POST["from"]);
			if ($results1) {
				foreach ($results1 as $result1) {
					$lat1 = $result1->lat;
					$lng1 = $result1->lng;
				}
			}
			$results2 = $wpdb->get_results('SELECT lat, lng FROM ' . $wpdb->prefix . 'flightlog_airports WHERE id=' . $_POST["to"]);
			if ($results2) {
				foreach ($results2 as $result2) {
					$lat2 = $result2->lat;
					$lng2 = $result2->lng;
				}
			}
			$dist = flightlog_calc_dist($lat1, $lng1, $lat2, $lng2);
			$dur = flightlog_calc_dur($dist);
			$wpdb->query($wpdb->prepare("INSERT INTO " . $wpdb->prefix . "flightlog_flights (user, dt, airport_from, airport_to, carrier, aircraft, distance, duration, ifr_vfr, day_night, approaches, landings, plane_id) VALUES (%d, %s, %d, %d, %d, %d, %d, %f, %s, %s, %d, %d, %s)", $current_user->ID, $_POST["dt"], $_POST["from"], $_POST["to"], $_POST["carrier"], $_POST["aircraft"], $dist, $dur, $_POST["ifr_vfr"], $_POST["day_night"], $_POST["approaches"], $_POST["landings"], $_POST["plane_id"]));
		}
	}

	else if (isset($_POST["Submit"]) && $_POST["Submit"] == 'Update') {
		if ($_POST['section'] == 'flight')
			$wpdb->query($wpdb->prepare("UPDATE " . $wpdb->prefix . "flightlog_flights SET distance=%d, duration=%f WHERE id=%d", $_POST["distance"], $_POST["duration"], $_POST["id"]));
		else if ($_POST['section'] == 'rem') {
			// We use the 'Update' button to create the record and to edit it, so first check if exists
//			$_POST['remark'] = esc_attr($_POST['remark']);
			$results_rem = $wpdb->get_results("SELECT flight_id FROM " . $wpdb->prefix . "flightlog_flights_remarks WHERE flight_id=" . $_POST['flight_id']);
			if ($results_rem)
				$wpdb->query($wpdb->prepare("UPDATE " . $wpdb->prefix . "flightlog_flights_remarks SET remark=%s WHERE flight_id=%d", $_POST['remark'], $_POST['flight_id']));
			else
				$wpdb->query($wpdb->prepare("INSERT INTO " . $wpdb->prefix . "flightlog_flights_remarks (flight_id, remark) VALUES (%d, %s)", $_POST['flight_id'], $_POST['remark']));
		}
	}

	else if (isset($_POST["Submit"]) && $_POST["Submit"] == 'Delete') {
		if ($_POST['section'] == 'flight') 
			$wpdb->query($wpdb->prepare("DELETE FROM " . $wpdb->prefix . "flightlog_flights WHERE id=" . $_POST["id"]));
		else if ($_POST['section'] == 'rem')
			$wpdb->query($wpdb->prepare("DELETE FROM " . $wpdb->prefix . "flightlog_flights_remarks WHERE flight_id=" . $_POST["flight_id"]));
		else if ($_POST['section'] == 'widgetlink') 
			update_option("flightlog_widgetlink_" . $current_user->user_login, "");
	}

	else if ($_POST['section'] == 'widgetlink')
		update_option("flightlog_widgetlink_" . $current_user->user_login, $_POST['found_post_id']);

	// Local styles and JS
	wp_enqueue_script('fl_js', plugins_url( 'flightlog.js' , __FILE__ ));
	wp_enqueue_script('fl_cal_js', plugins_url( 'jsDatePick.min.1.3.js	' , __FILE__ ));
	wp_enqueue_style('fl_css', plugins_url( 'flightlog.css' , __FILE__ ));
	wp_enqueue_style('fl_cal_css', plugins_url( 'jsDatePick_ltr.min.css' , __FILE__ ));

	// Header
	wp_enqueue_style('thickbox'); // needed for find posts div
	wp_enqueue_script('thickbox'); // needed for find posts div
	wp_enqueue_script('media');
	wp_enqueue_script('wp-ajax-response');
	$url = get_option("flightlog_widgetlink_" . $current_user->user_login);
	$widget_link = get_permalink($url);
	echo '<h3>'.__( 'FlightLog Entries', 'flightlog' ).'</h3>';
	echo '<table><tr><td>'.__( 'Widget link for ', 'flightlog' ).' ' . $current_user->display_name . ': ' . $widget_link . "</td>";
	echo '<td><form name="plugin_form" id="plugin_form" method="post" action="">';
	echo '<input type=hidden name=section value=widgetlink>';
	wp_nonce_field('plugin_nonce');
	find_posts_div();
	if ($url != "") 
	echo " <input type=submit name=Submit value=Delete> ";
	echo "<input type=button value=Find onclick=\"findPosts.open();return false;\"> ";
	echo "</form></td></tr></table>";
	echo '<hr />';

	// Show new record form
	echo '<form name="form_flight" id="form_flight" method="post" action="">';
	echo '<input type=hidden name=section value=flight>';
	echo '<p><b>'.__( 'Enter new flight', 'flightlog' ).'</b></p>';
	echo '<input type=text name="dt" id=dt size=10 placeholder=Date> ';

	flightlog_html_dropdown("flightlog_airports", "from", 1, 0);
	flightlog_html_dropdown("flightlog_airports", "to",  1, 0);
	flightlog_html_dropdown("flightlog_carriers", "carrier", 1, 0);
	flightlog_html_dropdown("flightlog_aircrafts", "aircraft", 1, 0);

	if ($flightlog_advanced == 1) {
		echo '</p><p>'.__( 'Advanced options', 'flightlog' ).':';
		flightlog_html_ifr_vfr(''); 
		flightlog_html_time('');
		flightlog_html_approaches('');
		flightlog_html_landings('');
		flightlog_html_plane_id('');
	}

	echo '<span id=submit_form_flight></span>';
	echo '</p>';
	echo '</form>';
	echo '<hr />';

	$today = getdate();

	echo '<script type="text/javascript">';
	echo '        window.onload = function(){';
	echo '                new JsDatePick({';
	echo '                        useMode:2,';
	echo '                        target:"dt",';
	echo '                        dateFormat:"%Y-%m-%d",';
	echo '                        selectedDate:{';
	echo '                                day:' . $today["mday"] . ',';        
	echo '                                month:' . $today["mon"] . ',';
	echo '                                year:' . $today["year"] . ',';
	echo '                        },';
	echo '                        limitToToday:true,';
	echo '                        imgPath:"/wp-content/plugins/flightlog/img/",';
	echo '                        weekStartDay:1';
	echo '                });';

	echo 'fl_form_dropdown(flightlog_airports, "flightlog_airports", "from", "-- From Airport --");';
	echo 'fl_form_dropdown(flightlog_airports, "flightlog_airports", "to", "-- To Airport --");';
	echo 'fl_form_dropdown(flightlog_carriers, "flightlog_carriers", "carrier", "-- Carrier --");';
	echo 'fl_form_dropdown(flightlog_aircrafts, "flightlog_aircrafts", "aircraft", "-- Aircraft --");';
	echo 'fl_form_submit("form_flight", "Add");';

	echo '        };';
	echo '</script>';

	// Display entries
	$results = $wpdb->get_results('SELECT ff.id, ff.dt, DATE_FORMAT(ff.dt, "%e.%b.%Y") AS dt2, ff.distance, ff.duration, ff.ifr_vfr, ff.day_night, ff.landings, ff.approaches, ff.plane_id, fa1.name AS from_name, fa1.iata AS from_iata, fa2.name AS to_name, fa2.iata AS to_iata, fc.name AS carrier, fp.name AS aircraft, fp.engines FROM ' . $wpdb->prefix . 'flightlog_flights ff JOIN ' . $wpdb->prefix . 'flightlog_airports fa1 ON fa1.id=ff.airport_from JOIN ' . $wpdb->prefix . 'flightlog_airports fa2 ON fa2.id=ff.airport_to JOIN ' . $wpdb->prefix . 'flightlog_carriers fc ON fc.id=ff.carrier JOIN ' . $wpdb->prefix . 'flightlog_aircrafts fp ON fp.id=ff.aircraft  WHERE user=' . $current_user->ID . ' ORDER BY dt, ff.id');
	if ($results) {
		$counter = 1;
		echo '<p><b>'.__( 'Flights for', 'flightlog').' ' . $current_user->display_name . '</b></p>';
		echo '<table cellpadding=2>';
		echo '<tr><td align=center><i>No</i></td> <td align=center><i>'.__( 'Date', 'flightlog').'</i></td> <td align=center><i>'.__('From', 'flightlog').'</i></td> <td align=center><i>'.__( 'To', 'flightlog').'</i></td> <td align=center><i>'.__( 'Carrier', 'flightlog').'</i></td> <td align=center><i>'.__( 'Aircraft', 'flightlog').'</i></td>';
		if ($flightlog_advanced)
			echo '<td align=center><i>'.__( 'Aircraft ID', 'flightlog').'</i></td><td align=center><i>'.__( 'Engines', 'flightlog').'</i></td>';
		echo '<td align=center><i>'.__( 'Distance', 'flightlog').'</i></td> <td align=center><i>'.__( 'Duration','flightlog').'</i></td>';
		if ($flightlog_advanced)
			echo '<td align=center><i>'.__( 'Flight Rules', 'flightlog').'</i></td><td align=center><i>'.__( 'Time', 'flightlog').'</i></td><td align=center><i>'.__( 'Approaches', 'flightlog').'</i></td><td align=center><i>'.__( 'Landings', 'flightlog').'</i></td><td align=center><i>'.__( 'Remarks', 'flightlog').'</i></td>';

		echo'</tr>';
		foreach ($results as $result) {
			echo '<tr>';
			echo '<td align=right>';
			$ifr_vfr = ($result->ifr_vfr) ? $result->ifr_vfr : "N/A";
			$day_night = ($result->day_night) ? $result->day_night : "N/A";
			$engines = ($result->engines) ? $result->engines : "N/A";
			$approaches = ($result->approaches) ? $result->approaches : "1";
			$landings = ($result->landings) ? $result->landings : "1";
			$plane_id = ($result->plane_id) ? $result->plane_id : "N/A";
			echo "<a href=# onClick=\"javascript:fl_overlay_add2(" . $result->id . ",'" . $result->dt2 . "','" . $result->from_name . "','" . $result->to_name . "','" .  $result->carrier . "','" . $result->aircraft . "','" . $result->distance . "','" . $result->duration . "','" . $flightlog_advanced . "','" . $ifr_vfr . "','" . $day_night . "','" . $engines . "','" . $approaches . "','" . $landings . "','" . $plane_id . "')\">";
			echo $counter . '.</td>';
			echo '<td>' . $result->dt2 . '</td>';
			echo '<td>' . $result->from_name . ' (' . $result->from_iata . ')</td>';
			echo '<td>' . $result->to_name . ' (' . $result->to_iata . ')</td>';
			echo '<td>' . $result->carrier . '</td>';
			echo '<td>' . $result->aircraft . '</td>';
			if ($flightlog_advanced) {
				echo '<td>' . $plane_id . '</td>';
				echo '<td>' . $engines . '</td>';
			}
			echo '<td align=right>' . $result->distance . '</td>';
			echo '<td>' . $result->duration . '</td>';
			if ($flightlog_advanced) {
				echo '<td>' . $ifr_vfr . '</td>';
				echo '<td>' . $day_night . '</td>';
				echo '<td>' . $approaches . '</td>';
				echo '<td>' . $landings . '</td>';
				echo '<td>';
				$results_rem = $wpdb->get_results('SELECT remark FROM ' . $wpdb->prefix . 'flightlog_flights_remarks WHERE flight_id=' . $result->id);
				if ($results_rem) {
					preg_match("/(\S+\s*){0,3}/", $results_rem[0]->remark, $res);
					$show = trim($res[0]);
					// Escape the single quote which will confuse the JS parser; 
					// also, place the text with the escaped single quotes in a variable - because the JS parser is veeeeeeeery picky. 
					$results_rem[0]->remark = str_replace("'", "\'", $results_rem[0]->remark);
					echo "<script language=javascript>var remark" . $result->id . "='" . $results_rem[0]->remark . "'</script>";
				}
				else {
					$show = "Add remark";
					// Clear the JS variable if now remark is set
					echo "<script language=javascript>var remark" . $result->id . "=''</script>";
				}
				echo '<a href=# onClick=\'javascript:fl_overlay_add_rem("' . $result->id . '", remark' . $result->id . ')\'>' . $show . '...</a>';
			}
			echo '</tr>';
			$counter++;
		}
		echo '</table>';
	}
}


// Widget

class FlightLog_Widget extends WP_Widget {
	public function __construct() {
		// widget actual processes
		parent::__construct(
	 		'flightlog_widget', // Base ID
			'FlightLog_Widget', // Name
			array( 'description' => __( 'FlightLog Widget', 'flightlog' ), ) // Args
		);
	}

 	public function form( $instance ) {
		// outputs the options form on admin
		if ( isset( $instance[ 'title' ] ) ) {
			$title = $instance[ 'title' ];
		}
		else {
			$title = __( 'New title', 'flightlog' );
		}
		?>
		<p>
		<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e( 'Title:' ); ?></label> 
		<input class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>" />
		</p>
		<?php 
	}

	public function update( $new_instance, $old_instance ) {
		// processes widget options to be saved
	        $instance = $old_instance;
        	$instance['title'] = strip_tags($new_instance['title']);
	        return $instance;
	}

	public function widget( $args, $instance ) {
		// outputs the content of the widget
	        global $current_user;
	        global $wpdb;
		global $flightlog_measures;

		extract( $args );
		$title = apply_filters( 'widget_title', $instance['title'] );

		echo $before_widget;
		if ( ! empty( $title ) )
			echo $before_title . $title . $after_title;

		$summaries = $wpdb->get_results("SELECT COUNT(*) AS cnt, SUM(distance) AS distance, ceil(SUM(duration)) AS duration, u.user_login, u.display_name FROM " . $wpdb->prefix . "flightlog_flights ff JOIN " . $wpdb->prefix . "users u ON ff.user=u.id GROUP BY user");
		if ($summaries) {
			echo '<ul>';
			foreach ($summaries as $summary) {
			        $url = get_option("flightlog_widgetlink_" . $summary->user_login);
			        $widget_link = get_permalink($url);
				echo '<li>';
				if ($url != "") 
					echo '<a href="'.$widget_link.'">';
				echo $summary->display_name . '</a>: ' . $summary->cnt . ', ' . $summary->distance;
				if ($flightlog_measures == 'Metric') 
					echo ' km, '; 
				else
					echo ' mi, ';
				echo $summary->duration . ' h.</li>';
			}
			echo "</ul>";
		}

		echo $after_widget;		
	}

}


function flightlog_ui( $atts ) {
	global $wpdb;
	global $flightlog_measures;
	global $flightlog_advanced;
	global $flightlog_gmaps_key;

	$map_date_from = '';
	$map_date_to = '';
	$from = 0;
	$to = 0;
	$carrier = 0;
	$aircraft = 0;
	$engines = 0;
	$plane_id = '';
	$ifr_vfr = '';
	$day_night = '';
	$approaches = '';
	$landings = '';

	// Local styles and JS
	wp_enqueue_script('fl_js', plugins_url( 'flightlog.js' , __FILE__ ));
	wp_enqueue_script('fl_cal_js', plugins_url( 'jsDatePick.min.1.3.js	' , __FILE__ ));
	wp_enqueue_style('fl_css', plugins_url( 'flightlog.css' , __FILE__ ));
	wp_enqueue_style('fl_cal_css', plugins_url( 'jsDatePick_ltr.min.css' , __FILE__ ));

	// Input from the web page insde the [flightlog] tags
	$input = shortcode_atts( array(
		'username' => '',
		'year_from' => '',
		'year_to' => '',
	), $atts);

	$where = "";
	$web = "";
	$year_from = 0;
	$year_to = 0;

	if ($input['year_from'] != '') {
		$web .= "from " . $input['year_from'] . " till now ";
		$where = " AND YEAR(dt)>=" . $input['year_from'];
		$map_date_from = $input['year_from'] . '-01-01';
	}
	if ($input['year_to'] != '') {
		$web .= " till " . $input['year_to'];
		$where = " AND YEAR(dt)<=" . $input['year_to'];
		$map_date_to = $input['year_to'] . '-01-01';
	}

	// Additional data from the advanced options (POST) - override defauls from web page
	if(isset($_POST["Submit"]) && $_POST["Submit"] == 'Filter') {
		if (isset($_POST['dt_from']) && strlen($_POST['dt_from']) > 0) {
			$map_date_from = $_POST['dt_from'];
			$where = ' AND dt >= \'' . $_POST['dt_from'] . '\'';
		}
		if (isset($_POST['dt_to']) && strlen($_POST['dt_to']) > 0) {
			$map_date_to = $_POST['dt_to'];
			$where .= ' AND dt <= \'' . $_POST['dt_to'] . '\'';
		}
		if (isset($_POST['from']) && $_POST['from'] > 0) {
			$from = $_POST['from'];
			$where .= ' AND fa1.id = ' . $_POST['from'];
		}
		if (isset($_POST['to']) && $_POST['to'] > 0) {
			$to = $_POST['to'];
			$where .= ' AND fa2.id = ' . $_POST['to'];
		}
		if (isset($_POST['carrier']) && $_POST['carrier'] > 0) {
			$carrier = $_POST['carrier'];
			$where .= ' AND fc.id = ' . $_POST['carrier'];
		}
		if (isset($_POST['aircraft']) && $_POST['aircraft'] > 0) {
			$aircraft = $_POST['aircraft'];
			$where .= ' AND fp.id = ' . $_POST['aircraft'];
		}
		if (isset($_POST['engines']) && $_POST['engines'] > 0) {
			$engines = $_POST['engines'];
			$where .= ' AND fp.engines = ' . $_POST['engines'];
		}
		if (isset($_POST['plane_id']) && strlen($_POST['plane_id']) > 0) {
			$plane_id = $_POST['plane_id'];
			$where .= ' AND plane_id = \'' . $_POST['plane_id'] . '\'';
		}
		if (isset($_POST['ifr_vfr']) && strlen($_POST['ifr_vfr']) > 1) {
			$ifr_vfr = $_POST['ifr_vfr'];
			$where .= ' AND ifr_vfr = \'' . $_POST['ifr_vfr'] . '\'';
		}
		if (isset($_POST['day_night']) && strlen($_POST['day_night']) > 1) {
			$day_night = $_POST['day_night'];
			$where .= ' AND day_night = \'' . $_POST['day_night'] . '\'';
		}
		if (isset($_POST['approaches']) && $_POST['approaches'] > 0) {
			$approaches = $_POST['approaches'];
			$where .= ' AND approaches = \'' . $_POST['approaches'] . '\'';
		}
		if (isset($_POST['landings']) && $_POST['landings'] > 0) {
			$landings = $_POST['landings'];
			$where .= ' AND landings = \'' . $_POST['landings'] . '\'';
		}
	}

	$user = get_user_by('login', $input['username']);
	if ($user->ID == 0)
		return;

	$summary = $wpdb->get_results("SELECT COUNT(*) AS cnt, SUM(distance) AS distance, ceil(SUM(duration)) AS duration, u.display_name FROM " . $wpdb->prefix . "flightlog_flights ff JOIN " . $wpdb->prefix . 'users u ON ff.user=u.id JOIN ' .  $wpdb->prefix . 'flightlog_airports fa1 ON fa1.id=ff.airport_from JOIN ' .  $wpdb->prefix . 'flightlog_airports fa2 ON fa2.id=ff.airport_to JOIN ' .  $wpdb->prefix . 'flightlog_carriers fc ON fc.id=ff.carrier JOIN ' .  $wpdb->prefix . 'flightlog_aircrafts fp ON fp.id=ff.aircraft WHERE user=' . $user->ID . $where);

	echo 'Map for user ' . $user->first_name;
	echo ($web != "") ? '(' . $web . ')' : ':';

	if ($flightlog_advanced) {
		echo '<br>'.__( 'Total flights' , 'flightlog' ).': ' . $summary[0]->cnt . ' -> ';
		echo __( 'Total distance' , 'flightlog' ).': ' . $summary[0]->distance;
		echo ($flightlog_measures == 'Metric') ? ' km' : ' mi';
		echo '->'.__( 'Total time', 'flightlog' ).': ' . $summary[0]->duration . ' h.';

		echo '<form name="form_filter" id="form_filter" method="post" action="">';
		echo '<table style="width:640px"><tr>';
		echo '<td style="vertical-align:top; width:200px">';
		echo '<input type=text name="dt_from" id=dt_from class="margin-zero" value="'.$map_date_from.'" placeholder="From (date)">';
		echo '<input type=text name="dt_to" id=dt_to class="margin-zero" value="'.$map_date_to.'" placeholder="To (date)">';
		flightlog_html_dropdown("flightlog_airports", "from", 0, $from);
		echo '<br>';
		flightlog_html_dropdown("flightlog_airports", "to", 0, $to);
		echo '</td><td style="vertical-align:top; width:200px">';
		flightlog_html_dropdown("flightlog_carriers", "carrier", 0, $carrier);
		echo '<br>';
		flightlog_html_dropdown("flightlog_aircrafts", "aircraft", 0, $aircraft);
		flightlog_html_aircraft($aircraft, true);
		echo '<br>';
		echo '<span id=flightlog_engines></span>';
		echo '<br>';
		flightlog_html_plane_id($plane_id, 'width-100-percent');
		echo '</td><td style="vertical-align:top; width:200px">';
		flightlog_html_ifr_vfr($ifr_vfr, 'width-100-percent') ;
		echo '<br>';
		flightlog_html_time($day_night, 'width-100-percent');
		echo '<br>';
		flightlog_html_approaches($approaches, 'width-100-percent');
		echo '<br>';
		flightlog_html_landings($landings, 'width-100-percent');
		echo '</td><td style="vertical-align:top">';
		echo '<span id=submit_form_filter></span>';
		echo '</td>';
		echo '</tr></table>';
		echo '</form>';

		$today = getdate();

		$date_from = $wpdb->get_results("SELECT dt FROM " . $wpdb->prefix . "flightlog_flights ff JOIN " . $wpdb->prefix . "users u ON ff.user=u.id WHERE user=" . $user->ID . " ORDER BY dt LIMIT 1");
		if (strlen($date_from[0]->dt) > 7)
			$date_from_parts = explode('-', $date_from[0]->dt);
		else {
			$date_from_parts[0] = $today["year"];
			$date_from_parts[1] = $today["mon"];
			$date_from_parts[2] = $today["mday"];			
		}

		echo '<script type="text/javascript">';
		echo '        var fl_ui_init = function(){';
		echo '                new JsDatePick({';
		echo '                        useMode:2,';
		echo '                        target:"dt_from",';
		echo '                        dateFormat:"%Y-%m-%d",';
		echo '                        selectedDate:{';
		echo '                                day:' . $date_from_parts[2] . ',';        
		echo '                                month:' . $date_from_parts[1] . ',';
		echo '                                year:' . $date_from_parts[0] . ',';
		echo '                        },';
		echo '                        limitToToday:true,';
		echo '                        imgPath:"/wp-content/plugins/flightlog/img/",';
		echo '                        weekStartDay:1';
		echo '                });';
		echo '                new JsDatePick({';
		echo '                        useMode:2,';
		echo '                        target:"dt_to",';
		echo '                        dateFormat:"%Y-%m-%d",';
		echo '                        selectedDate:{';
		echo '                                day:' . $today["mday"] . ',';        
		echo '                                month:' . $today["mon"] . ',';
		echo '                                year:' . $today["year"] . ',';
		echo '                        },';
		echo '                        limitToToday:true,';
		echo '                        imgPath:"/wp-content/plugins/flightlog/img/",';
		echo '                        weekStartDay:1';
		echo '                });';
	        echo 'fl_form_dropdown(flightlog_airports, "flightlog_airports", "from", "-- From Airport --");';
        	echo 'fl_form_dropdown(flightlog_airports, "flightlog_airports", "to", "-- To Airport --");';
	        echo 'fl_form_dropdown(flightlog_carriers, "flightlog_carriers", "carrier", "-- Carrier --");';
        	echo 'fl_form_dropdown(flightlog_aircrafts, "flightlog_aircrafts", "aircraft", "-- Aircraft --");';
                echo 'fl_form_engines(flightlog_aircrafts);';
	        echo 'fl_form_submit("form_filter", "Filter");';
                echo '        };';
		echo '</script>';
	}

	if (!$flightlog_advanced) {
		echo '<ul>';
		echo '<li>'.__( 'Total flights', 'flightlog').': ' . $summary[0]->cnt . '</li>';
		echo '<li>'.__( 'Total distance', 'flightlog').': ' . $summary[0]->distance;
		echo ($flightlog_measures == 'Metric') ? ' km' : ' mi';
		echo '</li><li>'.__( 'Total time', 'flightlog').': ' . $summary[0]->duration . ' h.</li>';
		echo "</ul>";
	}

	echo '<div id="flightlog_gmaps" style="width:640px; height:480px"></div>';
	echo '<script type="text/javascript" src="http://maps.googleapis.com/maps/api/js?key=' . $flightlog_gmaps_key . '&sensor=false"></script>'."\n";
	// Local styles and JS
	echo '<script language=javascript>window.onload=function(){';
	echo 'fl_gsux("'.plugins_url( 'kml.php' , __FILE__ ).'",'.$user->ID.',"'.$map_date_from.'","'.$map_date_to.'",'.$from.','.$to.','.$carrier.','.$aircraft.','.$engines.',"'.urlencode($plane_id).'","'.$ifr_vfr.'","'.$day_night.'","'.$approaches.'","'.$landings.'");';
	echo 'fl_gmaps();';
	if ($flightlog_advanced)
		echo 'fl_ui_init();'; 
	echo '}</script>';
}

// Hooks
register_activation_hook(__FILE__,'flightlog_db_create');
register_uninstall_hook(__FILE__, 'flightlog_db_delete');
add_action( 'plugins_loaded', 'flightlog_db_create' );
add_action('admin_menu', 'flightlog_admin_menu');
add_action( 'widgets_init', create_function( '', 'register_widget( "FlightLog_Widget" );' ) );
add_shortcode( 'flightlog', 'flightlog_ui' );

?>
